@@ -722,6 +722,9 @@ MISSINGPARAMETER = 'MissingParameter'
 # 缺少多个参数错误
 MISSINGPARAMETER_MULTIMISSINGPARAMETER = 'MissingParameter.MultiMissingParameter'
 
+# EIP实例开启了删除保护开关。
+OPERATIONDENIED_ADDRESSDELETIONPROTECTIONENABLED = 'OperationDenied.AddressDeletionProtectionEnabled'
+
 # 指定公网IP处于隔离状态。
 OPERATIONDENIED_ADDRESSINARREARS = 'OperationDenied.AddressInArrears'
 
@@ -947,6 +950,9 @@ UNSUPPORTEDOPERATION_DELETECCNEXISTCCNEXPRESSCONNECT = 'UnsupportedOperation.Del
 # VPN通道状态为更新中/销毁中/创建中，不支持此操作。
 UNSUPPORTEDOPERATION_DELETEVPNCONNINVALIDSTATE = 'UnsupportedOperation.DeleteVpnConnInvalidState'
 
+# NAT网关已开启删除保护，不允许删除
+UNSUPPORTEDOPERATION_DELETIONPROTECTIONENABLED = 'UnsupportedOperation.DeletionProtectionEnabled'
+
 # 发货失败。
 UNSUPPORTEDOPERATION_DELIVERYFAILED = 'UnsupportedOperation.DeliveryFailed'
 
@@ -1046,6 +1052,9 @@ UNSUPPORTEDOPERATION_INSTANCEORDINARYACCOUNTREFUSEATTACH = 'UnsupportedOperation
 # 该地址绑定的实例状态不支持此操作。
 UNSUPPORTEDOPERATION_INSTANCESTATENOTSUPPORTED = 'UnsupportedOperation.InstanceStateNotSupported'
 
+# 子机在关机不收费状态下不支持绑定EIP。
+UNSUPPORTEDOPERATION_INSTANCESTATUSNOTPERMIT = 'UnsupportedOperation.InstanceStatusNotPermit'
+
 # 账户余额不足。
 UNSUPPORTEDOPERATION_INSUFFICIENTFUNDS = 'UnsupportedOperation.InsufficientFunds'
 
